Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(293)

Unified Diff: components/omnibox/browser/verbatim_match.h

Issue 2738003002: Add title to current page in zero suggest. (Closed)
Patch Set: Remove debugging info. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/omnibox/browser/verbatim_match.h
diff --git a/components/omnibox/browser/verbatim_match.h b/components/omnibox/browser/verbatim_match.h
index 9b4f0b6c2b2edc1aadac1905db7325fef2ead973..cc5354d1ab444ab9d602700e09fbac898d095e84 100644
--- a/components/omnibox/browser/verbatim_match.h
+++ b/components/omnibox/browser/verbatim_match.h
@@ -16,13 +16,15 @@ class HistoryURLProvider;
// Returns a verbatim match for input.text() with a relevance of
// |verbatim_relevance|. If |verbatim_relevance| is negative then a default
// value is used. If the desired |destination_url| is already known and a
// |history_url_provider| is also provided, this may be more efficient (see
// implementation for details) than the default code path.
// input.text() must not be empty.
AutocompleteMatch VerbatimMatchForURL(
AutocompleteProviderClient* client,
const AutocompleteInput& input,
const GURL& destination_url,
+ const base::string16& destination_description,
HistoryURLProvider* history_url_provider,
int verbatim_relevance);
« no previous file with comments | « components/omnibox/browser/titled_url_match_utils_unittest.cc ('k') | components/omnibox/browser/verbatim_match.cc » ('j') | no next file with comments »
@@ -16,13 +16,15 @@ class HistoryURLProvider;
// |verbatim_relevance|. If |verbatim_relevance| is negative then a default
// value is used. If the desired |destination_url| is already known and a
-// |history_url_provider| is also provided, this may be more efficient (see
+// |history_url_provider| is also provided, use |destination_description| as the
+// description. Providing |history_url_provider| also may be more efficient (see
// implementation for details) than the default code path.
// input.text() must not be empty.

Powered by Google App Engine
This is Rietveld 408576698